﻿//使用するロケール 'en'は必須
var LocaleList = ['en', 'ja', 'fr']
//ロケール指定。無指定の場合はOS指定に従う
var Locale = 'en';
//表示更新周期 (ms)
var UpdateInterval = 20000;
//フォントサイズ指定。無指定の場合はxx-small,
var fontSize = 'x-small';

//地図の左端のタイムゾーン
var mapLeftTimeZone = -9;
//var mapLeftTimeZone = -1;
//地図全体の時間幅
var mapTimeSpan = 22;
//日陰オーバレイの左端の時刻
var shadowLeftHours = 6;
//日陰オーバレイ全体の時間幅
var shadowTimeSpan = 48;
//日陰オーバレイの透明度
var shadowOpacity = 45;

//Inner Frame
//URI
var InnerFrameHtml = '../calendar/calendar.html';
//X Alignment left, center or right
var InnerFrameXAlignment = 'center';
//X Position (px)
var InnerFrameX = 0;
//Width (px)
var InnerFrameWidth = 1000
//Y Alignment top, center or bottom
var InnerFrameYAlignment = 'top';
//Y Position (px)
var InnerFrameY = 0;
//Height (px)
var InnerFrameHeight = 70

/*
 * Cities 表示都市配列
 *
 * Name      各ロケールごとの表示名
 * OffsetX   Map上表示位置(左端が0)
 * OffsetY   Map上表示位置(上端が0)
 * LiftLabel 無し(false) = dotの横に地名、その下に時刻
 *           true        = dotの横に時刻、その上に地名
 * OffsetGMT 夏時間でない時のUTCとの時刻差(1=1時間)
 * OffsetDLS 夏時間種類指定(DSTMode配列内のIDを指定する)
 *           夏時間のない場合は'0'
 */
var Cities =
[
	{
		Name		: {en: 'San Francisco', ja: 'サンフランシスコ', fr: 'San Francisco'},
		OffsetX		: 62,
		OffsetY		: 430,
		OffsetGMT	: -8,
		OffsetDLS	: 'PDT'
	},
	{
		Name		: {en: 'Minneapolis', ja: 'ミネアポリス', fr: 'Minneapolis'},
		OffsetX		: 190,
		OffsetY		: 400,
		OffsetGMT	: -6,
		OffsetDLS	: 'CDT'
	},
	{
		Name		: {en: 'New York', ja: 'ニューヨーク', fr: 'New York'},
		OffsetX		: 265,
		OffsetY		: 439,
		OffsetGMT	: -5,
		OffsetDLS	: 'EDT'
	},
	{
		Name		: {en: 'Buenos-Aires', ja: 'ブエノスアイレス', fr: 'Buenos-Aires'},
		OffsetX		: 339,
		OffsetY		: 810,
		OffsetGMT	: -4,
		OffsetDLS	: '0'
	},
	{
		Name		: {en: 'London', ja: 'ロンドン', fr: 'Londres'},
		OffsetX		: 556,
		OffsetY		: 358,
		LiftLabel	: true,
		OffsetGMT	: 0,
		OffsetDLS	: 'BST'
	},
	{
		Name		: {en: 'Paris', ja: 'パリ', fr: 'Paris'},
		OffsetX		: 576,
		OffsetY		: 376,
		OffsetGMT	: 1,
		OffsetDLS	: 'CEST'
	},
	{
		Name		: {en: 'Moscow', ja: 'モスクワ', fr: 'Moscou'},
		OffsetX		: 776,
		OffsetY		: 286,
		OffsetGMT	: 3,
		OffsetDLS	: 'MST'
	},
	{
		Name		: {en: 'Beijing', ja: '北京', fr: 'P&eacute;kin'},
		OffsetX		: 1080,
		OffsetY		: 438,
		OffsetGMT	: 8,
		OffsetDLS	: '0'
	},
	{
		Name		: {en: 'Tokyo', ja: '東京', fr: 'Tokyo' },
		OffsetX		: 1168,
		OffsetY		: 450,
		OffsetGMT	: 9,
		OffsetDLS	: '0'
	},
	{
		Name		: {en: 'Sydney', ja: 'シドニー', fr: 'Sydney'},
		OffsetX		: 1218,
		OffsetY		: 796,
		OffsetGMT	: 10,
		OffsetDLS	: 'AEDT'
	},
	{
		Name		: {en: 'Addis Ababa', ja: 'アディスアベバ', fr: 'Addis-Abeba'},
		OffsetX		: 735,
		OffsetY		: 580,
		OffsetGMT	: 3,
		OffsetDLS	: '0'
	}
];

/*
 * TimeFormat ロケールごとの時刻表示フォーマット
 *
 * 24 = 24時間 それ以外は12時間表示
 */
var TimeFormat =
{
	en: 24,  
	ja: 24,  
	fr: 24
};

/*
 * DSTMode 夏時間指定配列
 *
 * ID      種類指定ID
 * Start   夏時間開始 (Month, WeekNumber, WeekDay, Hours)
 * End     夏時間終了 (Month, WeekNumber, WeekDay, Hours)
 * 		Month (1 ~ 12)
 *		Week Number (-1 = Last Week, 1~ )
 *		WeekDay (0 = Sunday ~ 6 = Saturday)
 *		Hours (0 ~ 23 夏時間でない時の時刻でこの時刻で切り替わる)
 */
var DSTMode =
[
	{
	//	アラスカ夏時間 (AKDT)
		ID		: 'AKDT',
		Start	: '3, 2, 0, 2',
		End		: '11, 1, 0, 2'
	},
	//	太平洋夏時間 (PDT)
	{
		ID		: 'PDT',
		Start	: '3, 2, 0, 2',
		End		: '11, 1, 0, 2'
	},
	//	山岳部夏時間 (MDT)
	{
		ID		: 'MDT',
		Start	: '3, 2, 0, 2',
		End		: '11, 1, 0, 2'
	},
	//	中部夏時間 (CDT)
	{
		ID		: 'CDT',
		Start	: '3, 2, 0, 2',
		End		: '11, 1, 0, 2'
	},
	//	東部夏時間 (EDT)
	{
		ID		: 'EDT',
		Start	: '3, 2, 0, 2',
		End		: '11, 1, 0, 2'
	},
	//	大西洋夏時間 (ADT)
	{
		ID		: 'ADT',
		Start	: '3, 2, 0, 2',
		End		: '11, 1, 0, 2'
	},
	//	ニューファンドランド夏時間 (NDT)
	{
		ID		: 'NDT',
		Start	: '4, 1, 0, 2',
		End		: '10, -1, 0, 2'
	},
	//	英国夏時間 (BST)
	{
		ID		: 'BST',
		Start	: '3, -1, 0, 1',
		End		: '10, -1, 0, 1'
	},
	//	西ヨーロッパ夏時間 (WEST)
	{
		ID		: 'WEST',
		Start	: '3, -1, 0, 1',
		End		: '10, -1, 0, 1'
	},
	//	中央ヨーロッパ夏時間 (CEST)
	{
		ID		: 'CEST',
		Start	: '3, -1, 0, 1',
		End		: '10, -1, 0, 1'
	},
	//	東ヨーロッパ夏時間 (EEST)
	{
		ID		: 'EEST',
		Start	: '3, -1, 0, 1',
		End		: '10, -1, 0, 1'
	},
	//	モスクワ夏時間 (MST)
	{
		ID		: 'MST',
		Start	: '3, -1, 0, 1',
		End		: '10, -1, 0, 1'
	},
	//	西アフリカ夏時間 (WAST)Start-Endは不正確
	{
		ID		: 'WAST',
		Start	: '9, 1, 0, 1',
		End		: '4, -1, 0, 1'
	},
	//	オーストラリア中部夏時間(ACDT)
	{
		ID		: 'ACDT',
		Start	: '10, 1, 0, 2',
		End		: '4, 1, 0, 3'
	},
	//	オーストラリア東部夏時間(AEDT)
	{
		ID		: 'AEDT',
		Start	: '10, 1, 0, 2',
		End		: '4, 1, 0, 3'
	},
	//	オーストラリア西部夏時間(AWDT)試行
	{
		ID		: 'AWDT',
		Start	: '10, -1, 0, 2',
		End		: '3, -1, 0, 3'
	}
]
